@@ -1,10 +1,12 @@
-from ...manifest.namings import alias_df
 from enum import Enum, IntEnum
-from .routing import routing_df
+
 from ...fold import ns_path
+from ...manifest.namings import alias_df
+from .routing import routing_df
 
 __all__ = ["AddressPath"]
 
+
 class AddressPart(str):
     def __new__(cls, *args, **kw):
         return super().__new__(cls, *args, **kw)
@@ -140,15 +142,13 @@ def pop_part(part_list):
         return e
 
 
-def interpret_filepath(address_path=None):
-    if address_path is None:
-        address_path = example_path
-    elif type(address_path) is str:
+def interpret_filepath(address_path):
+    if type(address_path) is str:
         address_path = AddressPath(address_path)
     namespace = address_path.namespace
     domain = address_path.domain
     route_query = f"namespace == '{namespace}' and domain == '{domain}'"
-    #route_result = routing_df.query(route_query)
+    # route_result = routing_df.query(route_query)
     custom_route = routing_df.query(route_query).route.item()
     route = custom_route if custom_route else domain
     domain_filepath = (ns_path / route).resolve()
@@ -157,6 +157,7 @@ def interpret_filepath(address_path=None):
     ]
     # Delayed to avoid circular import
     from ...fold.wire import standup
+
     standup_config = standup(domains_list=[domain], dry_config=True, verbose=False)
     if domain in standup_config:
         # The domain is being served, so get the directory from which it is served
@@ -189,7 +190,7 @@ class AddressPath(list):
     def __init__(self, address_str, sep="⠶"):
         self.sep = sep
         self.parts = SeparatedString(address_str, sep=sep)
-    
+
     @property
     def as_str(self, sep=None):
         if sep is None:
@@ -300,6 +301,7 @@ class AddressPath(list):
             path_parts.append(str(n))
         return cls(sep.join(path_parts))
 
+
 class SeparatedString(list):
     def __init__(self, sep_str, sep):
         self.extend(sep_str.split(sep))
